/*
 * ServerTaskException.cs
 *
 * Testing Framework
 * Version: 1.0
 *
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: real_vg, TCSDEVELOPER
 */

using System;
using NAnt.Core;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// The exception that is thrown by <see cref="ServerAppTestTask"/>
    /// when any exceptions occur while executing the task.
    /// </summary>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class ServerTaskException : BuildException
    {
        /// <summary>
        /// This variable stores the array of "inner" exceptions.
        /// These are the cause exceptions of this exception.
        /// It is initialized in constructor, immutable, and can be null.
        /// Elements may also be null.
        /// </summary>
        private readonly Exception[] innerExceptions;

        /// <summary>
        /// Gets the inner exceptions that caused the current exception.
        /// </summary>
        ///
        /// <value>
        /// An array of inner exceptions that caused the current exception.
        /// It could be null.
        /// </value>
        public Exception[] InnerExceptions
        {
            get
            {
                return innerExceptions;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ServerTaskException"/> class
        /// with a specified error message and a reference to the inner exceptions
        /// that are the cause of this exception.
        /// </summary>
        ///
        /// <remarks>
        /// If the given inner exception is not null, only the first element (if exists)
        /// is passed to the base class.
        /// </remarks>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        /// <param name="innerExceptions">
        /// The array of exceptions which caused this exception, can be null.
        /// </param>
        public ServerTaskException(string message, Exception[] innerExceptions)
            : base(message, ((innerExceptions != null) && (innerExceptions.Length > 0)) ? innerExceptions[0] : null)
        {
            this.innerExceptions = innerExceptions;
        }
    }
}
