/*
 * ConsoleCap.cs
 *
 * Testing Framework
 * Version: 1.0
 *
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved
 *
 * Author: TCSDEVELOPER
 */

using System;
using System.IO;

namespace TopCoder.Test.Framework.Tests
{
    /// <summary>
    /// Captures console output.
    /// </summary>
    ///
    /// <remarks>
    /// Please ensure that the instance is Disposed of in order to restore the console.
    /// </remarks>
    ///
    /// <threadsafety static="false" instance="false"/>
    public class ConsoleCap : IDisposable
    {
        /// <summary>
        /// The original console. Initialized in Ctor().
        /// </summary>
        private TextWriter originalConsole;

        /// <summary>
        /// The new redirected console. Initialized in Ctor().
        /// Console output will go here.
        /// </summary>
        private TextWriter newConsole;

        /// <summary>
        /// Gets the console output.
        /// </summary>
        ///
        /// <value>
        /// A string of console output.
        /// </value>
        public string Output
        {
            get
            {
                return newConsole.ToString();
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ConsoleCap"/> class.
        /// </summary>
        public ConsoleCap()
        {
            // save current console and redirect it to a StringWriter
            originalConsole = Console.Out;

            newConsole = new StringWriter();
            Console.SetOut(newConsole);
        }

        /// <summary>
        /// Disposes by restoring console.
        /// </summary>
        public void Dispose()
        {
            Console.SetOut(originalConsole);
            newConsole.Close();
        }
    }
}
