/*
 * DemoNUnitAsp.cs
 *
 * Testing Framework
 * Version: 1.0
 *
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved
 *
 * Author: TCSDEVELOPER
 */

using System.IO;
using NUnit.Framework;
using NUnit.Extensions.Asp;
using NUnit.Extensions.Asp.AspTester;

namespace TopCoder.Test.Framework.Tests
{
    /// <summary>
    /// The actual test that is executed by <see cref="Demo"/> via
    /// NAnt build file in test_files\ServerAppTest.build.
    /// </summary>
    ///
    /// <remarks>
    /// This demo will fail if run directly from standard NAnt because
    /// the files are not deployed yet.
    /// It is expected to be run by <see cref="Demo"/> which executes NAnt
    /// with ServerAppTest task which will initialize the IIS server.
    /// To prevent this class from being run by standard NAnt,
    /// a file-based communication mechanism is used.
    /// If the file test_files\RunByDemo exist, test cases are run;
    /// otherwise, it's ignored.
    /// </remarks>
    [TestFixture]
    public class DemoNUnitAsp : WebFormTestCase
    {
        /// <summary>
        /// If the file exists, test cases are run.
        /// </summary>
        public const string RunByDemoFile = @"..\..\test_files\RunByDemo";

        /// <summary>
        /// The base url where files are deployed to.
        /// </summary>
        private const string UrlBase = "http://localhost/Hello/";

        /// <summary>
        /// Tests Hello.aspx.
        /// It keys-in some message, click the submit button, and assert the result.
        /// </summary>
        [Test]
        public void DemoHello()
        {
            if (!File.Exists(RunByDemoFile))
            {
                return;
            }

            // this console output is to be used for assertion in Demo
            System.Console.WriteLine("In DemoHello");
            Browser.GetPage(UrlBase + "Hello.aspx");

            // tester objects
            TextBoxTester input = new TextBoxTester("Input", CurrentWebForm);
            ButtonTester button = new ButtonTester("Enter", CurrentWebForm);
            LabelTester message = new LabelTester("Message", CurrentWebForm);

            AssertEquals("Initially no message", "", message.Text);

            // submit a text
            input.Text = "Test from NAnt task";
            button.Click();

            AssertEquals("A message submitted", "Test from NAnt task", message.Text);
        }

        /// <summary>
        /// Tests plain.txt.
        /// Simply retrieve it and check its content.
        /// </summary>
        [Test]
        public void DemoPlain()
        {
            if (!File.Exists(RunByDemoFile))
            {
                return;
            }

            // this console output is to be used for assertion in Demo
            System.Console.WriteLine("In DemoPlain");
            Browser.GetPage(UrlBase + "Plain.txt");

            string content = TestHelper.ReadContent(@"..\..\test_files\deploysource\Plain.txt", false);
            AssertEquals("File content is different", content, Browser.CurrentPageText);
        }

        /// <summary>
        /// Tests sub/Default.htm.
        /// Simply retrieve it and check its content.
        /// </summary>
        [Test]
        public void DemoSub()
        {
            if (!File.Exists(RunByDemoFile))
            {
                return;
            }

            // this console output is to be used for assertion in Demo
            System.Console.WriteLine("In DemoSub");
            Browser.GetPage(UrlBase + "sub/Default.htm");

            string content = TestHelper.ReadContent(@"..\..\test_files\deploysource\sub\Default.htm", false);
            AssertEquals("File content is different", content, Browser.CurrentPageText);
        }
    }
}
